@@ -115,7 +115,8 @@ RequestGroupMan::RequestGroupMan
     removedLastErrorResult_(error_code::FINISHED),
     maxDownloadResult_(option->getAsInt(PREF_MAX_DOWNLOAD_RESULT)),
     wrDiskCache_(nullptr),
-    numOpenFile_(0)
+    numOpenFile_(0),
+    numStoppedTotal_(0)
 {
   appendReservedGroup(reservedGroups_,
                       requestGroups.begin(), requestGroups.end());
@@ -631,7 +632,7 @@ void RequestGroupMan::showDownloadResults(OutputFile& o, bool full) const
   }
   std::string line(pathRowSize, '=');
   o.printf("%s\n", line.c_str());
-  bool useColor = o.supportsColor();
+  bool useColor = o.supportsColor() && option_->getAsBool(PREF_ENABLE_COLOR);
   int ok = 0;
   int err = 0;
   int inpr = 0;
@@ -832,6 +833,7 @@ bool RequestGroupMan::removeDownloadResult(a2_gid_t gid)
 
 void RequestGroupMan::addDownloadResult(const std::shared_ptr<DownloadResult>& dr)
 {
+  ++numStoppedTotal_;
   bool rv = downloadResults_.push_back(dr->gid->getNumericId(), dr);
   assert(rv);
   while(downloadResults_.size() > maxDownloadResult_){
@@ -985,4 +987,10 @@ void RequestGroupMan::ensureMaxOpenFileLimit(size_t numNewFile)
   numOpenFile_ += numNewFile - numClose;
 }
 
+void RequestGroupMan::reduceNumOfOpenedFile(size_t numCloseFile)
+{
+  assert(numOpenFile_ >= numCloseFile);
+  numOpenFile_ -= numCloseFile;
+}
+
 } // namespace aria2
