@@ -43,17 +43,12 @@ namespace aria2 {
 class UTMetadataPostDownloadHandler:public PostDownloadHandler
 {
 private:
-  class Criteria:public RequestGroupCriteria
-  {
-  public:
-    virtual bool match(const RequestGroup* requestGroup) const CXX11_OVERRIDE;
-  };
 public:
   UTMetadataPostDownloadHandler();
 
   virtual void
   getNextRequestGroups(std::vector<std::shared_ptr<RequestGroup> >& groups,
-                       RequestGroup* requestGroup) CXX11_OVERRIDE;
+                       RequestGroup* requestGroup) const CXX11_OVERRIDE;
 };
 
 } // namespace aria2
